"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Input = void 0;
const react_1 = __importDefault(require("react"));
const defaultLayouts_1 = require("../../constants/defaultLayouts");
const stringGenerator_1 = require("../../helpers/stringGenerator");
const cursorTypes_1 = require("../../types/cursorTypes");
const CheckboxInput_1 = require("./inputs/CheckboxInput");
const EmailInput_1 = require("./inputs/EmailInput");
const FileInput_1 = require("./inputs/FileInput");
const HiddenInput_1 = require("./inputs/HiddenInput");
const NumberInput_1 = require("./inputs/NumberInput");
const PasswordInput_1 = require("./inputs/PasswordInput");
const RadioInput_1 = require("./inputs/RadioInput");
const TextInput_1 = require("./inputs/TextInput");
const styles_1 = require("./styles");
const inputTypes_1 = require("./types/inputTypes");
const Input = ({ className, id, name, type = inputTypes_1.InputTypes.TEXT, labelText, placeholder, helperText = "", icon, iconSize = defaultLayouts_1.DEFAULT_INPUT_ICON_SIZE, withShowHide, value, defaultValue, backgroundColor, textColor, containerPadding = defaultLayouts_1.DEFAULT_PADDING, containerMargin = defaultLayouts_1.DEFAULT_MARGIN, padding, margin, width, height, outline, border, borderRadius, cursor = cursorTypes_1.CursorType.DEFAULT, required = false, autoFocus = false, checked = false, disabled = false, error = "", errorBackgroundColor, errorTextColor, helperTextBackgroundColor, helperTextTextColor, onChange, onFocus, onBlur, }) => {
    let inputField;
    const inputId = id ? id : `input_${(0, stringGenerator_1.generateRandomString)()}`;
    switch (type) {
        case inputTypes_1.InputTypes.TEXT:
            inputField = (react_1.default.createElement(TextInput_1.TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue) }));
            break;
        case inputTypes_1.InputTypes.NUMBER:
            inputField = (react_1.default.createElement(NumberInput_1.NumberInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: Number(defaultValue) }));
            break;
        case inputTypes_1.InputTypes.PASSWORD:
            inputField = (react_1.default.createElement(PasswordInput_1.PasswordInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, withShowHide: withShowHide, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue), icon: icon, iconSize: iconSize }));
            break;
        case inputTypes_1.InputTypes.CHECKBOX:
            inputField = (react_1.default.createElement(CheckboxInput_1.CheckboxInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, icon: icon, iconSize: iconSize, checked: checked, labelText: labelText, textColor: textColor }));
            break;
        case inputTypes_1.InputTypes.EMAIL:
            inputField = (react_1.default.createElement(EmailInput_1.EmailInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue) }));
            break;
        case inputTypes_1.InputTypes.HIDDEN:
            inputField = (react_1.default.createElement(HiddenInput_1.HiddenInput, { className: className, name: name, id: inputId, type: type, value: value }));
            break;
        case inputTypes_1.InputTypes.RADIO:
            inputField = (react_1.default.createElement(RadioInput_1.RadioInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, checked: checked, textColor: textColor, labelText: labelText }));
            break;
        case inputTypes_1.InputTypes.FILE:
            inputField = (react_1.default.createElement(FileInput_1.FileInput, { className: className, name: name, id: id, type: type, padding: padding, margin: margin, required: required, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, icon: icon }));
            break;
        default:
            inputField = (react_1.default.createElement(TextInput_1.TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue) }));
            break;
    }
    return (react_1.default.createElement(styles_1.Container, { backgroundColor: backgroundColor, textColor: textColor, padding: containerPadding, margin: containerMargin, width: width, height: height, outline: outline, border: border, borderRadius: borderRadius, cursor: cursor }, inputField));
};
exports.Input = Input;
//# sourceMappingURL=Input.js.map