"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStyle = exports.FileHelperText = exports.Error = exports.InputField = exports.InputWrapper = exports.Label = exports.Container = void 0;
const styles_1 = require("@material-ui/styles");
const styled_components_1 = __importDefault(require("styled-components"));
const colors_1 = require("../../constants/colors");
const inputTypes_1 = require("./types/inputTypes");
exports.Container = styled_components_1.default.div `
  display: flex;
  flex-direction: column;
  justify-content: center;

  background-color: ${({ backgroundColor }) => backgroundColor};
  color: ${({ textColor }) => textColor};
  padding: ${({ padding }) => padding};
  margin: ${({ margin }) => margin};
  width: ${({ width }) => width};
  height: ${({ height }) => height};
  cursor: ${({ cursor }) => cursor};

  outline: ${({ outline }) => (outline ? outline : "none")};
  border: ${({ border }) => (border ? border : "none")};
  border-radius: ${({ borderRadius }) => (borderRadius ? borderRadius : "0")};
`;
exports.Label = styled_components_1.default.label `
  background-color: ${({ backgroundColor }) => backgroundColor};
  color: ${({ textColor }) => textColor};
`;
exports.InputWrapper = styled_components_1.default.div `
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
`;
exports.InputField = styled_components_1.default.input `
  padding: ${({ padding }) => padding};
  margin: ${({ margin }) => margin};
  width: ${({ type }) => [inputTypes_1.InputTypes.CHECKBOX, inputTypes_1.InputTypes.RADIO].includes(type) ? "auto" : "100%"};
  height: 100%;
  align-self: center;
  background-color: transparent;

  ${(props) => {
    switch (props.type) {
        case inputTypes_1.InputTypes.TEXT: {
            return `
          border: none;
          border-bottom: 1px solid ${colors_1.DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case inputTypes_1.InputTypes.PASSWORD: {
            return `
          border: none;
          border-bottom: 1px solid ${colors_1.DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case inputTypes_1.InputTypes.NUMBER: {
            return `
          border: none;
          border-bottom: 1px solid ${colors_1.DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case inputTypes_1.InputTypes.EMAIL: {
            return `
          border: none;
          border-bottom: 1px solid ${colors_1.DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case inputTypes_1.InputTypes.CHECKBOX: {
            const checkboxProps = props;
            return `
        ${checkboxProps.icon && "display: none"};
        & + .checkbox-checked-image {
          display: inline-block;
          width: ${checkboxProps.iconSize};
          height: ${checkboxProps.iconSize};
          background: transparent;
          margin-right: 10px;
          border: 1px solid ${colors_1.DEFAULT_PRIMARY};
        }
        &:checked + .checkbox-checked-image {
          background: url('${checkboxProps.icon}') no-repeat center center;
        }`;
        }
        case inputTypes_1.InputTypes.RADIO: {
            return ``;
        }
        case inputTypes_1.InputTypes.HIDDEN: {
            return ``;
        }
    }
}}
`;
exports.Error = styled_components_1.default.span `
  background-color: ${({ backgroundColor }) => backgroundColor};
  color: ${({ textColor }) => textColor};
`;
exports.FileHelperText = styled_components_1.default.span `
  font-size: 0.7rem;
  background-color: ${({ error, errorBackgroundColor, helperText, helperTextBackgroundColor, }) => error
    ? errorBackgroundColor || "transparent"
    : helperText
        ? helperTextBackgroundColor || "transparent"
        : "transparent"};
  color: ${({ error, errorTextColor, helperText, helperTextTextColor }) => error
    ? errorTextColor || "#000"
    : helperText
        ? helperTextTextColor || "#000"
        : "#000"};
`;
exports.useStyle = (0, styles_1.makeStyles)({
    root: ({ padding, margin, textColor, icon }) => (Object.assign({ padding,
        margin, width: "100%", color: textColor && `${textColor} !IMPORTANT`, backgroundColor: "transparent !IMPORTANT" }, (icon && { boxShadow: "none" }))),
    textColor: ({ textColor }) => ({
        color: textColor && `${textColor} !IMPORTANT`,
    }),
    error: ({ errorBackgroundColor, errorTextColor }) => ({
        backgroundColor: errorBackgroundColor && `${errorBackgroundColor} !IMPORTANT`,
        color: errorTextColor && `${errorTextColor} !IMPORTANT`,
    }),
    helperText: ({ helperTextBackgroundColor, helperTextTextColor, }) => ({
        backgroundColor: helperTextBackgroundColor && `${helperTextBackgroundColor} !IMPORTANT`,
        color: helperTextTextColor && `${helperTextTextColor} !IMPORTANT`,
    }),
});
//# sourceMappingURL=styles.js.map