/// <reference types="react" />
import { InputTypes } from "./inputTypes";
export interface InputProps {
    className?: string;
    id?: string;
    name?: string;
    type?: InputTypes;
    labelText?: string;
    helperText?: string;
    placeholder?: string;
    icon?: string | JSX.Element;
    iconSize?: string;
    withShowHide?: boolean;
    value?: string | number;
    defaultValue?: string | number | boolean;
    backgroundColor?: string;
    textColor?: string;
    labelBackgroundColor?: string;
    labelTextColor?: string;
    containerPadding?: string;
    containerMargin?: string;
    padding?: string;
    margin?: string;
    width?: string;
    height?: string;
    outline?: string;
    border?: string;
    borderRadius?: string;
    cursor?: string;
    required?: boolean;
    autoFocus?: boolean;
    checked?: boolean;
    disabled?: boolean;
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    helperTextBackgroundColor?: string;
    helperTextTextColor?: string;
    onChange?: (...args: any) => void;
    onFocus?: (...args: any) => void;
    onBlur?: (...args: any) => void;
}
export interface BaseInputProps {
    className?: string;
    name?: string;
    id?: string;
    type: InputTypes;
    value?: string | number;
    padding?: string;
    margin?: string;
    required?: boolean;
    autoFocus?: boolean;
    disabled?: boolean;
    onChange?: (...args: any) => void;
    onFocus?: (...args: any) => void;
    onBlur?: (...args: any) => void;
}
export interface TextInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    helperTextBackgroundColor?: string;
    helperTextTextColor?: string;
    textColor?: string;
    labelText?: string;
    helperText?: string;
    defaultValue?: string;
}
export interface NumberInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    helperTextBackgroundColor?: string;
    helperTextTextColor?: string;
    textColor?: string;
    labelText?: string;
    helperText?: string;
    defaultValue?: number;
}
export interface PasswordInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    withShowHide?: boolean;
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    helperTextBackgroundColor?: string;
    helperTextTextColor?: string;
    textColor?: string;
    labelText?: string;
    helperText?: string;
    defaultValue?: string;
}
export interface EmailInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    helperTextBackgroundColor?: string;
    helperTextTextColor?: string;
    textColor?: string;
    labelText?: string;
    helperText?: string;
    defaultValue?: string;
}
export interface CheckboxInputProps extends BaseInputProps {
    icon?: string | JSX.Element;
    iconSize?: string;
    checked?: boolean;
    labelText?: string;
    textColor?: string;
}
export declare type HiddenInputProps = BaseInputProps;
export interface RadioInputProps extends BaseInputProps {
    checked?: boolean;
    textColor?: string;
    labelText?: string;
}
export interface FileInputProps extends BaseInputProps {
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    helperTextBackgroundColor?: string;
    helperTextTextColor?: string;
    textColor?: string;
    labelText?: string;
    helperText?: string;
    icon?: JSX.Element;
}
export declare type InputType = TextInputProps | PasswordInputProps | NumberInputProps | EmailInputProps | CheckboxInputProps | HiddenInputProps | RadioInputProps | FileInputProps;
