"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Table = exports.DEFAULT_ITEMS_PER_PAGE = void 0;
const core_1 = require("@material-ui/core");
const classnames_1 = __importDefault(require("classnames"));
const react_1 = __importDefault(require("react"));
const EmptyState_1 = require("./DataState/EmptyState");
const ErrorState_1 = require("./DataState/ErrorState");
const styles_1 = require("./styles");
const TableBody_1 = require("./TableBody/TableBody");
const TableFooter_1 = require("./TableFooter/TableFooter");
const TableHead_1 = require("./TableHead/TableHead");
const TableLoadingState_1 = require("./TableLoadingState/TableLoadingState");
exports.DEFAULT_ITEMS_PER_PAGE = 10;
const Table = ({ data, columns, actions, border, pagination = true, onRowClick, error, loading, selectKey = "id", customStyle, className, paginationClassName, actionsNotification, EmptyStateComponent, hoverableTableRow = true, totalItems, page, limit, rowsPerPageOptions, tableFilters, order, orderBy, setPage, setLimit, setTableFilters, setOrderBy, selectedRows = [], tableStatus, setTableStatus, isDisabled, collapsableRows = false, ExpandableRowContent, hasSummaryRow = false, SummaryRowContent, isHighlighted, hiddenHeader, resizeColumns, hideErrorHeader, }) => {
    const classes = (0, styles_1.useStyle)({ border, customStyle, hiddenHeader });
    const renderEmptyState = () => EmptyStateComponent || react_1.default.createElement(EmptyState_1.EmptyState, null);
    const shouldShowEmptyState = !(data === null || data === void 0 ? void 0 : data.length) && !loading && !error;
    const hasFooter = pagination;
    return (react_1.default.createElement("div", { className: classes.tableWrapper },
        react_1.default.createElement(core_1.TableContainer, { className: (0, classnames_1.default)(classes.root, className) },
            react_1.default.createElement(core_1.Table, { className: classes.table, stickyHeader: true },
                react_1.default.createElement(TableHead_1.TableHead, { columns: columns, border: border, customStyle: customStyle, actions: actions, tableStatus: tableStatus, setTableStatus: setTableStatus, order: order, orderBy: orderBy, setOrderBy: setOrderBy, hidden: hiddenHeader, resizeColumns: resizeColumns }),
                react_1.default.createElement(TableBody_1.TableBody, { columns: columns, data: data, actionsNotification: actionsNotification, selectedRows: selectedRows, selectKey: selectKey, actions: actions, tableStatus: tableStatus, setTableStatus: setTableStatus, setTableFilters: setTableFilters, filters: tableFilters, border: border, hidden: loading || Boolean(error), customStyle: customStyle, hoverableTableRow: hoverableTableRow, onRowClick: onRowClick, isDisabled: isDisabled, collapsableRows: collapsableRows, ExpandableRowContent: ExpandableRowContent, isHighlighted: isHighlighted, hiddenHeader: hiddenHeader }),
                loading && react_1.default.createElement(TableLoadingState_1.TableLoadingState, { actions: actions, columns: columns })),
            shouldShowEmptyState && renderEmptyState(),
            error && !loading && (react_1.default.createElement(ErrorState_1.ErrorState, { messages: [undefined, error.message], hideErrorHeader: hideErrorHeader }))),
        !error && !loading && hasSummaryRow && !!SummaryRowContent && (react_1.default.createElement(SummaryRowContent, { data: data, columns: columns })),
        hasFooter && (react_1.default.createElement(TableFooter_1.TableFooter, { pagination: pagination, paginationClassName: paginationClassName, totalItems: totalItems, limit: limit, page: page, rowsPerPageOptions: rowsPerPageOptions, setTableStatus: setTableStatus, setLimit: setLimit, setPage: setPage }))));
};
exports.Table = Table;
//# sourceMappingURL=Table.js.map