"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableConfirmActions = exports.ROW_ACTIONS_WIDTH = void 0;
const core_1 = require("@material-ui/core");
const Check_1 = __importDefault(require("@material-ui/icons/Check"));
const Close_1 = __importDefault(require("@material-ui/icons/Close"));
const lab_1 = require("@material-ui/lab");
const notistack_1 = require("notistack");
const react_1 = __importDefault(require("react"));
const getActionsCount_1 = require("../../../helpers/getActionsCount");
const types_1 = require("../types");
exports.ROW_ACTIONS_WIDTH = 30;
const TableConfirmActions = ({ row, newRow, notify = true, setRow, actions, tableStatus, setTableStatus, }) => {
    const { rowActions } = (0, getActionsCount_1.getActionsCount)(actions);
    const { enqueueSnackbar } = (0, notistack_1.useSnackbar)();
    const resetTableStatus = {
        errors: undefined,
        tableMode: undefined,
        activeRow: undefined,
        loading: undefined,
    };
    const handleActionCancel = (event) => {
        event.stopPropagation();
        setRow === null || setRow === void 0 ? void 0 : setRow({});
        setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus(resetTableStatus);
    };
    const runAction = () => __awaiter(void 0, void 0, void 0, function* () {
        var _a, _b, _c;
        const tableMode = tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode;
        try {
            setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus({ loading: true });
            switch (tableMode) {
                case types_1.TableMode.EDIT:
                    yield ((_a = actions === null || actions === void 0 ? void 0 : actions.onRowEdit) === null || _a === void 0 ? void 0 : _a.call(actions, newRow, row));
                    notify &&
                        enqueueSnackbar("Successfully Saved", {
                            variant: "success",
                            autoHideDuration: 1000,
                        });
                    break;
                case types_1.TableMode.DELETE:
                    yield ((_b = actions === null || actions === void 0 ? void 0 : actions.onRowDelete) === null || _b === void 0 ? void 0 : _b.call(actions, row));
                    notify &&
                        enqueueSnackbar("Successfully Removed", {
                            variant: "success",
                            autoHideDuration: 1000,
                        });
                    break;
                case types_1.TableMode.ADD:
                    yield ((_c = actions === null || actions === void 0 ? void 0 : actions.onRowAdd) === null || _c === void 0 ? void 0 : _c.call(actions, row));
                    notify &&
                        enqueueSnackbar("Successfully Saved", {
                            variant: "success",
                            autoHideDuration: 1000,
                        });
                    break;
            }
        }
        catch (error) {
            notify && enqueueSnackbar("Action failed");
        }
        finally {
            setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus(resetTableStatus);
        }
    });
    const handleActionConfirm = (event) => __awaiter(void 0, void 0, void 0, function* () {
        event.stopPropagation();
        yield runAction();
    });
    return (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.loading) ? (react_1.default.createElement(lab_1.Skeleton, { width: exports.ROW_ACTIONS_WIDTH * rowActions, animation: "pulse" })) : (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(core_1.Tooltip, { title: "Confirm" },
            react_1.default.createElement(core_1.IconButton, { size: "small", "aria-label": "confirm", onClick: handleActionConfirm },
                react_1.default.createElement(Check_1.default, null))),
        react_1.default.createElement(core_1.Tooltip, { title: "Cancel" },
            react_1.default.createElement(core_1.IconButton, { size: "small", "aria-label": "cancel", onClick: handleActionCancel },
                react_1.default.createElement(Close_1.default, null)))));
};
exports.TableConfirmActions = TableConfirmActions;
//# sourceMappingURL=TableConfirmActions.js.map