"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableColumnFilter = void 0;
const date_fns_1 = __importDefault(require("@date-io/date-fns"));
const core_1 = require("@material-ui/core");
const pickers_1 = require("@material-ui/pickers");
const classnames_1 = __importDefault(require("classnames"));
const react_1 = __importDefault(require("react"));
const types_1 = require("../types");
const TableColumnFilter = ({ columns, onChange, filters, classes, hasActions, }) => {
    const defaultDateFormat = "yyyy-MM-dd";
    const label = "Filter";
    return (react_1.default.createElement(core_1.TableRow, null,
        hasActions && react_1.default.createElement(core_1.TableCell, { className: classes.filterRowCell }),
        columns.map((column, inputIndex) => {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
            if (column.columnFilter !== false && column.field !== "id") {
                switch (column.type) {
                    case "amount":
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(core_1.TextField, { type: "number", value: filters[column.field] || "", size: "small", label: label, variant: "outlined", margin: "none", onChange: (e) => onChange(e, column) })));
                    case "date":
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(pickers_1.MuiPickersUtilsProvider, { utils: date_fns_1.default },
                                react_1.default.createElement(pickers_1.DatePicker, { value: filters[column.field] || null, format: defaultDateFormat, label: label, size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column);
                                    } }))));
                    case "date-range":
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(pickers_1.MuiPickersUtilsProvider, { utils: date_fns_1.default },
                                react_1.default.createElement(pickers_1.DatePicker, { value: ((_a = filters[column.field]) === null || _a === void 0 ? void 0 : _a[0]) || null, format: defaultDateFormat.replace(/[:Hms]/g, ""), label: "Date From", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column);
                                    }, maxDate: ((_b = filters[column.field]) === null || _b === void 0 ? void 0 : _b[1]) || null }),
                                react_1.default.createElement(pickers_1.DatePicker, { value: ((_c = filters[column.field]) === null || _c === void 0 ? void 0 : _c[1]) || null, format: defaultDateFormat.replace(/[:Hms]/g, ""), label: "Date To", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column, false);
                                    }, minDate: ((_d = filters[column.field]) === null || _d === void 0 ? void 0 : _d[0]) || null }))));
                    case "date-time-range":
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(pickers_1.MuiPickersUtilsProvider, { utils: date_fns_1.default },
                                react_1.default.createElement(pickers_1.DateTimePicker, { value: ((_e = filters[column.field]) === null || _e === void 0 ? void 0 : _e[0]) || null, format: defaultDateFormat, label: "Date From", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column);
                                    }, maxDate: ((_f = filters[column.field]) === null || _f === void 0 ? void 0 : _f[1]) || null }),
                                react_1.default.createElement(pickers_1.DateTimePicker, { value: ((_g = filters[column.field]) === null || _g === void 0 ? void 0 : _g[1]) || null, format: defaultDateFormat, label: "Date To", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column, false);
                                    }, minDate: ((_h = filters[column.field]) === null || _h === void 0 ? void 0 : _h[0]) || null }))));
                    case "amount-range":
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(core_1.TextField, { type: "number", value: ((_j = filters[column.field]) === null || _j === void 0 ? void 0 : _j[0]) || "", size: "small", label: "Min", variant: "outlined", margin: "none", onChange: (e) => {
                                    onChange(e, column);
                                } }),
                            react_1.default.createElement(core_1.TextField, { type: "number", value: ((_k = filters[column.field]) === null || _k === void 0 ? void 0 : _k[1]) || "", size: "small", label: "Max", variant: "outlined", margin: "none", onChange: (e) => {
                                    onChange(e, column, false);
                                } })));
                    case "lookup":
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: (0, classnames_1.default)(classes.filterRowCell, "lookup"), align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(core_1.TextField, { value: filters[column.field] || "", name: column.field, onChange: (e) => {
                                    onChange(e, column);
                                }, select: true, variant: "outlined", size: "small", label: label },
                                react_1.default.createElement(core_1.MenuItem, null,
                                    react_1.default.createElement("em", null, "None")),
                                Object.values(column.filterEnum || []).map((option, i) => (react_1.default.createElement(core_1.MenuItem, { key: i, value: option || "" }, column.filterEnum
                                    ? column.filterEnumOptionsLabel
                                    : option))))));
                    default:
                        return (react_1.default.createElement(core_1.TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || types_1.TableColumnAlign.LEFT },
                            react_1.default.createElement(core_1.TextField, { variant: "outlined", size: "small", placeholder: "filter", fullWidth: true, onChange: (e) => {
                                    onChange(e, column);
                                }, value: filters[column.field] || "", label: label })));
                }
            }
            else {
                return react_1.default.createElement(core_1.TableCell, { className: classes.emptyCell, key: inputIndex });
            }
        })));
};
exports.TableColumnFilter = TableColumnFilter;
//# sourceMappingURL=TableColumnFilter.js.map