"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableInputCell = void 0;
const core_1 = require("@material-ui/core");
const react_1 = __importDefault(require("react"));
const react_number_format_1 = __importDefault(require("react-number-format"));
const formatDate_1 = require("../../../helpers/formatDate");
const getFieldValue_1 = require("../../../helpers/getFieldValue");
const styles_1 = require("../styles");
const TableInputCell = ({ clearError, setRow, value, hasError, errorMessage, field, column, onChange, }) => {
    const classes = (0, styles_1.useStyle)({});
    const { hasThousandsSeparator, thousandsSeparator, hasDecimalSeparator, decimalSeparator, } = formatDate_1.defaultAmountFormat;
    const commonProps = {
        value,
        error: hasError,
        helperText: errorMessage,
        defaultValue: column.defaultValue,
        InputProps: {
            classes: {
                input: classes.inputLabel,
            },
        },
    };
    if (column.type === "amount") {
        return (react_1.default.createElement(react_number_format_1.default, Object.assign({}, commonProps, { value: commonProps.value, customInput: core_1.TextField, thousandSeparator: hasThousandsSeparator ? thousandsSeparator : ",", decimalSeparator: hasDecimalSeparator ? decimalSeparator : ".", decimalScale: 2, fixedDecimalScale: true, onChange: undefined, onValueChange: (values) => {
                if (onChange) {
                    onChange(values.floatValue, setRow);
                }
                else {
                    setRow === null || setRow === void 0 ? void 0 : setRow((prevState) => (Object.assign(Object.assign({}, prevState), { [field]: values.floatValue })));
                }
            } })));
    }
    else if (column.type === "checkbox") {
        return (react_1.default.createElement(core_1.Checkbox, { checked: !!value, onChange: (event) => {
                const value = (0, getFieldValue_1.getFieldValue)(event.target);
                if (onChange) {
                    onChange(value, setRow);
                }
                else {
                    setRow === null || setRow === void 0 ? void 0 : setRow((prevState) => (Object.assign(Object.assign({}, prevState), { [field]: value })));
                }
            }, inputProps: { "aria-label": "checkbox" } }));
    }
    return (react_1.default.createElement(core_1.TextField, Object.assign({}, commonProps, { type: column.type || "text", onChange: (event) => {
            event.persist();
            clearError();
            const value = (0, getFieldValue_1.getFieldValue)(event.target);
            if (onChange) {
                onChange(value, setRow);
            }
            else {
                setRow === null || setRow === void 0 ? void 0 : setRow((prevState) => (Object.assign(Object.assign({}, prevState), { [field]: value })));
            }
        } })));
};
exports.TableInputCell = TableInputCell;
//# sourceMappingURL=TableInputCell.js.map