"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableRenderCell = void 0;
const core_1 = require("@material-ui/core");
const FileCopy_1 = __importDefault(require("@material-ui/icons/FileCopy"));
const lodash_1 = require("lodash");
const notistack_1 = require("notistack");
const react_1 = __importStar(require("react"));
const formatDate_1 = require("../../../helpers/formatDate");
const getNumberFormat_1 = require("../../../helpers/getNumberFormat");
const FormatDate_1 = require("../FormatField/FormatDate");
const FormatNumber_1 = require("../FormatField/FormatNumber");
const styles_1 = require("../TableRow/styles");
const types_1 = require("../types");
const styles_2 = require("./styles");
const TableRenderCell = ({ column, row, editMode, }) => {
    const classes = (0, styles_1.useTableRowStyles)();
    const renderCellClasses = (0, styles_2.useTableRenderCellStyles)();
    const [isShown, setIsShown] = (0, react_1.useState)(false);
    const { enqueueSnackbar } = (0, notistack_1.useSnackbar)();
    const additionalCellProps = column.additionalCellProps &&
        typeof column.additionalCellProps === "function"
        ? column.additionalCellProps(row)
        : column.additionalCellProps;
    const displayCell = (0, react_1.useCallback)(() => {
        switch (column.type) {
            case "amount":
            case "amount-range":
                return (react_1.default.createElement(core_1.Typography, { className: row[column.field] < 0
                        ? renderCellClasses.negativeAmount
                        : "" },
                    react_1.default.createElement(FormatNumber_1.FormatNumber, { value: row[column.field] })));
            case "date":
            case "date-range":
            case "date-time-range":
                return react_1.default.createElement(FormatDate_1.FormatDate, { value: row[column.field] });
            case "checkbox":
                return (react_1.default.createElement(core_1.Checkbox, { checked: !!row[column.field], disabled: true, className: classes.displayCheckbox }));
            default:
                return row[column.field];
        }
    }, [
        column.field,
        column.type,
        row,
        classes,
        renderCellClasses.negativeAmount,
    ]);
    const handleCopyClick = () => {
        const cell = displayCell();
        let cellText = "";
        if (typeof cell === "object" && "format" in (cell || {})) {
            cellText = cell.format;
        }
        else {
            switch (column.type) {
                case "date":
                case "date-range":
                    cellText = (0, formatDate_1.formatDate)(row[column.field]);
                    break;
                case "amount":
                    cellText = (0, getNumberFormat_1.getNumberFormat)(row[column.field]);
                    break;
                case "checkbox":
                    cellText = (!!row[column.field]).toString();
                    break;
                default:
                    cellText = cell;
            }
        }
        navigator.clipboard.writeText(cellText);
        enqueueSnackbar("Copied to Clipboard", {
            variant: "success",
            autoHideDuration: 1000,
        });
    };
    // eslint-disable-next-line react-hooks/exhaustive-deps
    const debounceOpen = (0, react_1.useCallback)((0, lodash_1.debounce)(() => setIsShown(!editMode && !!row[column.field]), 300), [setIsShown]);
    const TooltipDisplayContent = (0, react_1.useMemo)(() => column.type === "checkbox"
        ? (!!row[column.field]).toString()
        : displayCell(), [displayCell, column.type, column.field, row]);
    return (react_1.default.createElement(core_1.Tooltip, { classes: { tooltip: classes.copyTooltip, popper: classes.copyPopper }, title: react_1.default.createElement(core_1.Tooltip, { title: column.modifier
                ? column.modifier(row)
                : TooltipDisplayContent },
            react_1.default.createElement(core_1.IconButton, { size: "small", "aria-label": "copy-to-clipboard", className: classes.copyTooltipButton, color: "primary", onClick: (e) => {
                    e.stopPropagation();
                    handleCopyClick();
                } },
                react_1.default.createElement(FileCopy_1.default, { fontSize: "small" }))), enterDelay: 1000, placement: "top-end", interactive: true, onOpen: debounceOpen, onClose: () => {
            debounceOpen.cancel();
            setIsShown(false);
        }, open: isShown },
        react_1.default.createElement(core_1.TableCell, Object.assign({}, (additionalCellProps || {}), { align: column.align || types_1.TableColumnAlign.LEFT, className: classes.slimmerRow }),
            column.modifier ? column.modifier(row) : displayCell(),
            editMode && react_1.default.createElement(core_1.FormHelperText, null))));
};
exports.TableRenderCell = TableRenderCell;
//# sourceMappingURL=TableRenderCell.js.map