import { IconButton, Paper, Typography } from "@material-ui/core";
import { KeyboardArrowLeft, KeyboardArrowRight } from "@material-ui/icons";
import classNames from "classnames";
import React, { useState, useEffect, useCallback } from "react";
import { DEFAULT_BORDER_RADIUS, DEFAULT_CLASSNAME, DEFAULT_HEIGHT, DEFAULT_INTERVAL, DEFAULT_WIDTH, } from "../../constants/defaultLayouts";
import { useBasicImageSliderStyles } from "./styles";
export const BasicImageSlider = ({ images, showCaption = false, className = DEFAULT_CLASSNAME, buttonHeight = DEFAULT_HEIGHT, buttonBorderRadius = DEFAULT_BORDER_RADIUS, containerWidth = DEFAULT_WIDTH, containerHeight = DEFAULT_HEIGHT, imgWidth = DEFAULT_HEIGHT, imgHeight = DEFAULT_HEIGHT, interval = DEFAULT_INTERVAL, }) => {
    var _a;
    const [activeIndex, setActiveIndex] = useState(0);
    const classes = useBasicImageSliderStyles({
        buttonHeight,
        buttonBorderRadius,
        containerWidth,
        containerHeight,
        imgWidth,
        imgHeight,
    });
    const handleNext = useCallback(() => {
        setActiveIndex((prevIndex) => (prevIndex + 1) % images.length);
    }, [setActiveIndex, images.length]);
    const handlePrevious = () => {
        setActiveIndex((prevIndex) => (prevIndex + images.length - 1) % images.length);
    };
    useEffect(() => {
        if (interval === 0) {
            return;
        }
        const intervalId = setInterval(handleNext, interval);
        return () => clearInterval(intervalId);
    }, [interval, handleNext]);
    return (React.createElement("div", { className: classNames(classes.basicImageSliderContainer, className) },
        React.createElement(Paper, { className: classes.paper },
            React.createElement("img", { className: classes.imageContainer, src: images[activeIndex].url, alt: images[activeIndex].alt }),
            React.createElement("div", { className: classNames(classes.buttonContainer, classes.buttonLeft) },
                React.createElement(IconButton, { className: classes.iconButton, onClick: handlePrevious },
                    React.createElement(KeyboardArrowLeft, null))),
            React.createElement("div", { className: classNames(classes.buttonContainer, classes.buttonRight) },
                React.createElement(IconButton, { className: classes.iconButton, onClick: handleNext },
                    React.createElement(KeyboardArrowRight, null))),
            showCaption && ((_a = images[activeIndex]) === null || _a === void 0 ? void 0 : _a.caption) ? (React.createElement(Typography, { variant: "h6", className: classes.caption }, images[activeIndex].caption)) : null)));
};
//# sourceMappingURL=BasicImageSlider.js.map