import { Card as MuiCard, CardContent, CardActions, CardHeader, } from "@material-ui/core";
import classNames from "classnames";
import React from "react";
import { DEFAULT_PRIMARY, DEFAULT_PRIMARY_HOVER, DEFAULT_SECONDARY, DEFAULT_SECONDARY_HOVER, NONE, AUTO, UNSET, DEFAULT_CARD_BOX_SHADOW, } from "../../constants/colors";
import { DEFAULT_CURSOR, DEFAULT_PADDING, DEFAULT_MARGIN, DEFAULT_WIDTH, DEFAULT_HEIGHT, } from "../../constants/defaultLayouts";
import { FooterContainer, TitleWrapper, useStyles } from "./styles";
export const Card = ({ className, id, children = null, padding = DEFAULT_PADDING, margin = DEFAULT_MARGIN, outline = NONE, border = NONE, hoverBorder = NONE, width = AUTO, maxWidth = DEFAULT_WIDTH, height = DEFAULT_HEIGHT, maxHeight = AUTO, backgroundColor = DEFAULT_PRIMARY, textColor = DEFAULT_SECONDARY, hoverBackground = DEFAULT_PRIMARY_HOVER, hoverTextColor = DEFAULT_SECONDARY_HOVER, borderRadius = UNSET, cursor = DEFAULT_CURSOR, onClick, onFocus, onBlur, headerTitle, headerButton = null, headerContent = null, footerTitle, footerContent, footerButton = null, boxShadow = DEFAULT_CARD_BOX_SHADOW, }) => {
    const classes = useStyles({
        padding,
        margin,
        outline,
        boxShadow,
        border,
        hoverBorder,
        maxWidth,
        width,
        height,
        maxHeight,
        backgroundColor,
        textColor,
        hoverBackground,
        hoverTextColor,
        borderRadius,
        cursor,
    });
    const renderHeader = () => (React.createElement(CardHeader, { title: headerTitle, action: headerButton, subheader: headerContent }));
    const renderFooter = () => {
        if (footerContent) {
            return (React.createElement(FooterContainer, { className: "card-footer", withContent: true }, footerContent));
        }
        if (footerTitle && footerButton) {
            return (React.createElement(FooterContainer, { className: "card-footer", withTitle: true, withButton: true },
                React.createElement(TitleWrapper, null, footerTitle),
                footerButton));
        }
        if (footerTitle) {
            return (React.createElement(FooterContainer, { className: "card-footer", withTitle: true },
                React.createElement(TitleWrapper, null, footerTitle)));
        }
        if (footerButton) {
            return (React.createElement(FooterContainer, { className: "card-footer", withButton: true }, footerButton));
        }
        return null;
    };
    return (React.createElement(MuiCard, { className: classNames(classes.root, className), id: id, onClick: onClick, onFocus: onFocus, onBlur: onBlur },
        renderHeader(),
        React.createElement(CardContent, { className: classes.content }, children),
        (footerButton || footerContent || footerTitle) && (React.createElement(CardActions, null, renderFooter()))));
};
//# sourceMappingURL=Card.js.map