import { TextField, Popover, Button, Box } from "@material-ui/core";
import classNames from "classnames";
import { get } from "lodash";
import { usePopupState, bindTrigger, bindPopover, } from "material-ui-popup-state/hooks";
import React from "react";
import { HexColorPicker } from "react-colorful";
import { Controller, useFormContext } from "react-hook-form";
import { useColorPickerStyles } from "./styles";
export const ColorPicker = ({ name, label, id, className, required = false, fieldRequiredText = "Required", validationErrorText = "Value must be a valid HEX color", placeholderText = "HEX Color", width, height, maxWidth, maxHeight, padding, margin, }) => {
    const { watch, setValue, formState: { errors }, } = useFormContext();
    const popupState = usePopupState({
        variant: "popover",
        popupId: "colorPickerPopover",
    });
    const color = watch(name) || undefined;
    const classes = useColorPickerStyles({
        color,
        width,
        height,
        maxWidth,
        maxHeight,
        padding,
        margin,
    });
    const validationRules = {
        required: required && fieldRequiredText,
        pattern: {
            value: /^#{1}([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$/,
            message: validationErrorText,
        },
    };
    return (React.createElement(Box, { display: "flex", alignItems: "baseline", className: classNames(classes.root) },
        React.createElement(Popover, Object.assign({}, bindPopover(popupState), { anchorOrigin: {
                vertical: "bottom",
                horizontal: "left",
            }, transformOrigin: {
                vertical: "top",
                horizontal: "left",
            }, classes: { paper: classes.popoverPaper } }),
            React.createElement(HexColorPicker, { color: color, onChange: (value) => setValue(name, value, { shouldValidate: true }) })),
        React.createElement(Button, Object.assign({ variant: "contained" }, bindTrigger(popupState), { className: classes.pickerButton })),
        React.createElement(Controller, { name: name, rules: validationRules, defaultValue: "", render: ({ field: { value, onChange } }) => {
                var _a;
                return (React.createElement(TextField, { error: !!get(errors, name), id: id, className: className, label: label, value: value, onChange: onChange, helperText: (_a = get(errors, name)) === null || _a === void 0 ? void 0 : _a.message, InputLabelProps: {
                        shrink: true,
                    }, placeholder: placeholderText }));
            } })));
};
//# sourceMappingURL=ColorPicker.js.map