import DateFnsUtils from "@date-io/date-fns";
import { DateTimePicker as MuiDateTimePicker, DatePicker as MuiDatePicker, TimePicker as MuiTimePicker, MuiPickersUtilsProvider, } from "@material-ui/pickers";
import classNames from "classnames";
import React from "react";
import { AUTO } from "../../constants/colors";
import { useStyle } from "./styles";
import { DatePickerTypes } from "./types";
export const DatePicker = ({ className, id, name, value = null, type = DatePickerTypes.DATE_PICKER, width, height, maxWidth = AUTO, maxHeight = AUTO, padding, margin, backgroundColor, format, labelText, disabled = false, disablePast = false, onChange, onFocus, onBlur, }) => {
    const classes = useStyle({
        width,
        height,
        maxHeight,
        maxWidth,
        padding,
        margin,
        backgroundColor,
    });
    switch (type) {
        case DatePickerTypes.DATE_PICKER:
            return (React.createElement(MuiPickersUtilsProvider, { utils: DateFnsUtils },
                React.createElement(MuiDatePicker, { className: classNames(classes.root, className), id: id, name: name, value: value, format: format, onChange: onChange, onFocus: onFocus, onBlur: onBlur, label: labelText, disablePast: disablePast, disabled: disabled })));
        case DatePickerTypes.TIME_PICKER:
            return (React.createElement(MuiPickersUtilsProvider, { utils: DateFnsUtils },
                React.createElement(MuiTimePicker, { className: classNames(classes.root, className), id: id, name: name, value: value, format: format, onChange: onChange, onFocus: onFocus, onBlur: onBlur, label: labelText, disabled: disabled })));
        case DatePickerTypes.DATE_TIME_PICKER:
            return (React.createElement(MuiPickersUtilsProvider, { utils: DateFnsUtils },
                React.createElement(MuiDateTimePicker, { className: classNames(classes.root, className), id: id, name: name, value: value, format: format, onChange: onChange, onFocus: onFocus, onBlur: onBlur, label: labelText, disablePast: disablePast, disabled: disabled })));
        default:
            return null;
    }
};
//# sourceMappingURL=DatePicker.js.map