var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Button, Checkbox, Dialog, DialogActions, DialogContent, DialogTitle, Divider, FormControlLabel, Grid, IconButton, InputBase, LinearProgress, List, ListItem, ListItemIcon, ListItemText, Paper, Typography, } from "@material-ui/core";
import ArrowDropDownIcon from "@material-ui/icons/ArrowDropDown";
import CloseIcon from "@material-ui/icons/Close";
import ErrorIcon from "@material-ui/icons/Error";
import ListIcon from "@material-ui/icons/List";
import SearchIcon from "@material-ui/icons/Search";
import classNames from "classnames";
import { debounce } from "lodash";
import React, { useCallback, useEffect, useMemo, useState, } from "react";
import InfiniteScroll from "react-infinite-scroll-component";
import { useDialogSelectStyles } from "./styles";
const START_PAGE = 1;
const getDefaultInputElement = ({ onOpen, value, label, classes, }) => {
    const noValuePlaceholder = (React.createElement(Typography, { className: classes.noValuePlaceholder }, label));
    const displayValue = React.createElement(Typography, null, value);
    return (React.createElement(Button, { onClick: onOpen, className: classes.selectButton, endIcon: React.createElement(ArrowDropDownIcon, null) }, value ? displayValue : noValuePlaceholder));
};
export const DialogSelect = ({ value, onChange, getOptions, retrieveOnSearch, localization = {}, InputComponent, closeOnSelect, hidden, allowMulti = false, defaultOpen = false, headerActionElement, loadOptionsByDefault = false, totalItems, dataLimit = 25, infiniteScroll = false, disableOption, DisabledOptionContent, onClose, primaryColor, primaryTextColor, primaryHoverColor, primaryHoverTextColor, }) => {
    const classes = useDialogSelectStyles({
        primaryColor,
        primaryTextColor,
        primaryHoverColor,
        primaryHoverTextColor,
    });
    const [search, setSearch] = useState("");
    const [searchInputValue, setSearchInputValue] = useState("");
    const [open, setOpen] = useState(defaultOpen);
    const [fetchByDefault, setFetchByDefault] = useState(loadOptionsByDefault);
    const [options, setOptions] = useState([]);
    const [loading, setLoading] = useState(false);
    const [error, setError] = useState(null);
    const [page, setPage] = useState(START_PAGE);
    const [selectedOptions, setSelectedOptions] = useState([]);
    const [initialValue, setInitialValue] = useState(value);
    const areAllOptionsSelected = allowMulti && (value === null || value === void 0 ? void 0 : value.length) === options.length;
    const noSelectedOptions = !selectedOptions.length;
    const { placeholder = "Field", noDataTitle = "No data", noDataSubTitle = "Try searching for something else", errorTitle = "Error", errorSubTitle = "There was an error when retrieving the data", searchPlaceholder = "Search", doneButton = "Done", resetButton = "Close", selectAllButton = "Select All", deselectAllButton = "Deselect All", } = localization;
    // if paginated, fetch selected options to make sure they're initially
    // displayed in case they're not in the 1st results page
    useEffect(() => {
        if (!infiniteScroll) {
            return;
        }
        const hasValue = initialValue && Array.isArray(initialValue)
            ? initialValue.length > 0
            : initialValue;
        if (!hasValue) {
            return;
        }
        let unmounted = false;
        const fetchSelected = () => __awaiter(void 0, void 0, void 0, function* () {
            let initialValueSearch;
            let filterValues;
            if (Array.isArray(initialValue)) {
                const values = initialValue.map((value) => 
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                typeof value === "object" ? value.id : value);
                filterValues = values.length ? values : undefined;
            }
            else if (typeof initialValue === "object") {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                initialValueSearch = initialValue.id;
            }
            else {
                initialValueSearch = initialValue;
            }
            if (!filterValues && !initialValueSearch) {
                return;
            }
            const existingOptions = yield (getOptions === null || getOptions === void 0 ? void 0 : getOptions(initialValueSearch, undefined, undefined, filterValues));
            if (!unmounted) {
                setInitialValue(undefined);
                if (!existingOptions) {
                    return;
                }
                setSelectedOptions(existingOptions.filter(({ id }) => {
                    if (Array.isArray(initialValue)) {
                        return (initialValue.find((value) => typeof value === "object"
                            ? // eslint-disable-next-line @typescript-eslint/no-explicit-any
                                value.id === id
                            : value === id) !== undefined);
                    }
                    else if (typeof initialValue === "object") {
                        // eslint-disable-next-line @typescript-eslint/no-explicit-any
                        return initialValue.id === id;
                    }
                    return initialValue === id;
                }));
            }
        });
        fetchSelected();
        return function cancel() {
            unmounted = true;
        };
    }, [initialValue, getOptions, infiniteScroll]);
    useEffect(() => {
        let unmounted = false;
        const resolveOptions = () => __awaiter(void 0, void 0, void 0, function* () {
            if (!retrieveOnSearch || search) {
                setLoading(true);
                setError(null);
                try {
                    if (open || fetchByDefault) {
                        const rawOptions = yield (getOptions === null || getOptions === void 0 ? void 0 : getOptions(search, dataLimit, START_PAGE));
                        if (!unmounted && rawOptions) {
                            setOptions(rawOptions);
                            setFetchByDefault(false);
                        }
                    }
                }
                catch (e) {
                    if (!unmounted) {
                        setError(e);
                    }
                }
                finally {
                    if (!unmounted) {
                        setLoading(false);
                    }
                }
            }
        });
        resolveOptions();
        return function cancel() {
            unmounted = true;
        };
    }, [getOptions, retrieveOnSearch, search, open, fetchByDefault, dataLimit]);
    // set selected options if initial value exists when not using infinite pagination
    useEffect(() => {
        if (!infiniteScroll && initialValue && options.length) {
            setSelectedOptions(options.filter(({ id }) => {
                if (Array.isArray(initialValue)) {
                    return (initialValue.find((value) => typeof value === "object"
                        ? // eslint-disable-next-line @typescript-eslint/no-explicit-any
                            value.id === id
                        : value === id) !== undefined);
                }
                else if (typeof initialValue === "object") {
                    // eslint-disable-next-line @typescript-eslint/no-explicit-any
                    return initialValue.id === id;
                }
                return initialValue === id;
            }));
            setInitialValue(undefined);
        }
    }, [infiniteScroll, initialValue, options]);
    useEffect(() => {
        // reset page when it closes if paginated
        if (!open && infiniteScroll) {
            setPage(START_PAGE);
            setOptions([]);
        }
    }, [open, value, infiniteScroll]);
    useEffect(() => {
        if (!value && !noSelectedOptions) {
            setSelectedOptions([]);
        }
    }, [value, noSelectedOptions]);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    const debouncedSearchChange = useCallback(debounce((value) => setSearch(value), 500), []);
    const handleClickOpen = () => {
        setOpen(true);
    };
    const handleClose = () => {
        setOpen(false);
        onClose === null || onClose === void 0 ? void 0 : onClose();
        if (search) {
            setPage(START_PAGE);
        }
    };
    const handleReset = () => {
        onChange === null || onChange === void 0 ? void 0 : onChange(null);
        setOpen(false);
        onClose === null || onClose === void 0 ? void 0 : onClose();
        setSelectedOptions([]);
    };
    const getNextOptions = useCallback(() => __awaiter(void 0, void 0, void 0, function* () {
        if (!open) {
            return;
        }
        try {
            setLoading(true);
            setError(null);
            const rawOptions = yield (getOptions === null || getOptions === void 0 ? void 0 : getOptions(search, dataLimit, page + 1));
            if (rawOptions) {
                setOptions((prevOptions) => [...prevOptions, ...rawOptions]);
            }
            setPage((prevPage) => prevPage + 1);
        }
        catch (error) {
            setError(error);
        }
        finally {
            setLoading(false);
        }
    }), [getOptions, search, dataLimit, page, open]);
    const handleChange = (newValue, option) => {
        if (closeOnSelect) {
            handleClose();
        }
        if (!allowMulti) {
            onChange === null || onChange === void 0 ? void 0 : onChange(newValue, option);
            setSelectedOptions([option]);
            return;
        }
        let actualValues = value || [];
        const index = typeof newValue === "string"
            ? actualValues.indexOf(newValue)
            : actualValues.findIndex(
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            (entry) => entry.id === newValue.id);
        if (index !== -1) {
            actualValues = [
                ...actualValues.slice(0, index),
                ...actualValues.slice(index + 1),
            ];
        }
        else {
            actualValues = [...actualValues, newValue];
        }
        onChange === null || onChange === void 0 ? void 0 : onChange(actualValues);
        // update selected options to keep track of items
        // that are not found in the 1st results page
        setSelectedOptions((prevOptions) => {
            const selectedIndex = prevOptions.findIndex((entry) => entry.id === option.id);
            let updatedOptions = prevOptions;
            if (selectedIndex !== -1) {
                updatedOptions = [
                    ...updatedOptions.slice(0, selectedIndex),
                    ...updatedOptions.slice(selectedIndex + 1),
                ];
            }
            else {
                updatedOptions = [...updatedOptions, option];
            }
            return updatedOptions;
        });
    };
    const handleSelectAllChange = (_e) => {
        const selectedAllOptions = options.map((option) => (option.value || option.id));
        onChange === null || onChange === void 0 ? void 0 : onChange(areAllOptionsSelected ? [] : selectedAllOptions);
        setSelectedOptions(areAllOptionsSelected ? [] : options);
    };
    const selected = useMemo(() => {
        if (allowMulti) {
            const selectedForMulti = options.filter((option) => Array.isArray(value) &&
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                value.some((entry) => typeof entry === "object"
                    ? option.id === entry.id
                    : entry === option.id));
            if (selectedForMulti.length === 0 ||
                (selectedOptions.length &&
                    selectedForMulti.length !== selectedOptions.length)) {
                return selectedOptions;
            }
            else {
                return selectedForMulti;
            }
        }
        const selectedForSingle = options.find((option) => option.id === value);
        return selectedForSingle || selectedOptions[0];
    }, [allowMulti, options, selectedOptions, value]);
    const defaultValue = value || (allowMulti ? [] : "");
    const currentValue = selected
        ? allowMulti
            ? selected.map(({ label }) => label).join(", ")
            : selected === null || selected === void 0 ? void 0 : selected.label
        : defaultValue;
    const getInputElement = () => {
        const props = {
            value: currentValue,
            secondary: Array.isArray(currentValue)
                ? undefined
                : selected === null || selected === void 0 ? void 0 : selected.secondary,
            onOpen: handleClickOpen,
            label: placeholder,
            classes,
        };
        return (InputComponent === null || InputComponent === void 0 ? void 0 : InputComponent(props)) || getDefaultInputElement(props);
    };
    if (hidden) {
        return React.createElement(React.Fragment, null);
    }
    return (React.createElement(React.Fragment, null,
        getInputElement(),
        React.createElement(Dialog, { open: open, onClose: handleClose, PaperProps: { className: classes.paper }, scroll: "paper" },
            loading && React.createElement(LinearProgress, null),
            React.createElement(DialogTitle, { className: classes.dialogTitle },
                React.createElement(Paper, { component: "form", className: classes.searchRoot },
                    React.createElement(IconButton, { className: classes.iconButton, "aria-label": "menu", disabled: !search, onClick: () => {
                            setSearchInputValue("");
                            setSearch("");
                            setOptions([]);
                            setPage(START_PAGE);
                        } },
                        React.createElement(CloseIcon, null)),
                    React.createElement(InputBase, { value: searchInputValue, onChange: (e) => {
                            if (!e.target.value) {
                                setOptions([]);
                            }
                            setPage(START_PAGE);
                            setSearchInputValue(e.target.value);
                            debouncedSearchChange(e.target.value);
                        }, className: classes.input, placeholder: searchPlaceholder, inputProps: { "aria-label": "search input" } }),
                    React.createElement(Divider, { className: classes.divider, orientation: "vertical" }),
                    React.createElement(IconButton, { className: classes.iconButton, "aria-label": "directions" },
                        React.createElement(SearchIcon, null))),
                headerActionElement),
            React.createElement(DialogContent, { className: classes.dialogContent },
                React.createElement(List, { id: "scrollableContainer", className: classes.list, component: Paper },
                    React.createElement(InfiniteScroll, { dataLength: options.length, next: getNextOptions, hasMore: (totalItems || options.length) > options.length, loader: React.createElement(React.Fragment, null), scrollableTarget: "scrollableContainer" }, options.map((option) => {
                        const isDisabled = disableOption
                            ? disableOption(option)
                            : false;
                        const isChecked = allowMulti && Array.isArray(value)
                            ? // eslint-disable-next-line @typescript-eslint/no-explicit-any
                                value.some((entry) => typeof entry === "object" && entry !== null
                                    ? entry.id === option.id
                                    : entry === option.id)
                            : option.id === value;
                        return (React.createElement(ListItem
                        // eslint-disable-next-line @typescript-eslint/no-explicit-any
                        , { 
                            // eslint-disable-next-line @typescript-eslint/no-explicit-any
                            button: !isDisabled, dense: true, key: `item-${option.id}`, onClick: () => {
                                if (isDisabled) {
                                    return;
                                }
                                handleChange(option.value || option.id, option);
                            }, className: classNames({ [classes.disabled]: isDisabled }) },
                            React.createElement(ListItemIcon, null,
                                React.createElement(Checkbox, { disabled: isDisabled, checked: !isDisabled && isChecked, className: classes.checkboxColors, style: {
                                        color: primaryColor,
                                    } })),
                            React.createElement(ListItemText, { primary: option.label, secondary: option.secondary, primaryTypographyProps: { variant: "subtitle2" } }),
                            isDisabled && (DisabledOptionContent === null || DisabledOptionContent === void 0 ? void 0 : DisabledOptionContent(option))));
                    })),
                    (!options.length || error) && (React.createElement("div", { className: classes.emptyState },
                        React.createElement("div", { className: classes.emptyStateIcon }, error ? React.createElement(ErrorIcon, null) : React.createElement(ListIcon, null)),
                        React.createElement(Typography, { align: "center", variant: "h6", color: "textSecondary", component: "strong" }, error ? errorTitle : noDataTitle),
                        React.createElement(Typography, { align: "center", variant: "body1", color: "textSecondary", component: "p" }, error ? errorSubTitle : noDataSubTitle))))),
            React.createElement(DialogActions, { className: classes.actions },
                React.createElement(Grid, { container: true, item: true, xs: 12, spacing: 1 },
                    React.createElement(Grid, { item: true, xs: 6 }, allowMulti && (React.createElement(FormControlLabel, { control: React.createElement(Checkbox, { size: "small", checked: areAllOptionsSelected, onChange: handleSelectAllChange, className: classes.checkboxColors, style: {
                                color: primaryColor,
                            } }), labelPlacement: "end", label: areAllOptionsSelected ? deselectAllButton : selectAllButton, checked: areAllOptionsSelected, value: areAllOptionsSelected }))),
                    React.createElement(Grid, { item: true, xs: 3 },
                        React.createElement(Button, { onClick: handleReset }, resetButton)),
                    React.createElement(Grid, { item: true, xs: 3 }, !closeOnSelect && (React.createElement(Button, { onClick: handleClose, variant: "contained", color: "secondary", className: classes.inputColors }, doneButton))))))));
};
//# sourceMappingURL=DialogSelect.js.map