import React from "react";
import { DEFAULT_INPUT_ICON_SIZE, DEFAULT_MARGIN, DEFAULT_PADDING, } from "../../constants/defaultLayouts";
import { generateRandomString } from "../../helpers/stringGenerator";
import { CursorType } from "../../types/cursorTypes";
import { CheckboxInput } from "./inputs/CheckboxInput";
import { EmailInput } from "./inputs/EmailInput";
import { FileInput } from "./inputs/FileInput";
import { HiddenInput } from "./inputs/HiddenInput";
import { NumberInput } from "./inputs/NumberInput";
import { PasswordInput } from "./inputs/PasswordInput";
import { RadioInput } from "./inputs/RadioInput";
import { TextInput } from "./inputs/TextInput";
import { Container } from "./styles";
import { InputTypes } from "./types/inputTypes";
export const Input = ({ className, id, name, type = InputTypes.TEXT, labelText, placeholder, helperText = "", icon, iconSize = DEFAULT_INPUT_ICON_SIZE, withShowHide, value, defaultValue, backgroundColor, textColor, containerPadding = DEFAULT_PADDING, containerMargin = DEFAULT_MARGIN, padding, margin, width, height, outline, border, borderRadius, cursor = CursorType.DEFAULT, required = false, autoFocus = false, checked = false, disabled = false, error = "", errorBackgroundColor, errorTextColor, helperTextBackgroundColor, helperTextTextColor, onChange, onFocus, onBlur, }) => {
    let inputField;
    const inputId = id ? id : `input_${generateRandomString()}`;
    switch (type) {
        case InputTypes.TEXT:
            inputField = (React.createElement(TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue) }));
            break;
        case InputTypes.NUMBER:
            inputField = (React.createElement(NumberInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: Number(defaultValue) }));
            break;
        case InputTypes.PASSWORD:
            inputField = (React.createElement(PasswordInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, withShowHide: withShowHide, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue), icon: icon, iconSize: iconSize }));
            break;
        case InputTypes.CHECKBOX:
            inputField = (React.createElement(CheckboxInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, icon: icon, iconSize: iconSize, checked: checked, labelText: labelText, textColor: textColor }));
            break;
        case InputTypes.EMAIL:
            inputField = (React.createElement(EmailInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue) }));
            break;
        case InputTypes.HIDDEN:
            inputField = (React.createElement(HiddenInput, { className: className, name: name, id: inputId, type: type, value: value }));
            break;
        case InputTypes.RADIO:
            inputField = (React.createElement(RadioInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, checked: checked, textColor: textColor, labelText: labelText }));
            break;
        case InputTypes.FILE:
            inputField = (React.createElement(FileInput, { className: className, name: name, id: id, type: type, padding: padding, margin: margin, required: required, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, icon: icon }));
            break;
        default:
            inputField = (React.createElement(TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, error: error, errorBackgroundColor: errorBackgroundColor, errorTextColor: errorTextColor, helperTextBackgroundColor: helperTextBackgroundColor, helperTextTextColor: helperTextTextColor, textColor: textColor, labelText: labelText, helperText: helperText, defaultValue: String(defaultValue) }));
            break;
    }
    return (React.createElement(Container, { backgroundColor: backgroundColor, textColor: textColor, padding: containerPadding, margin: containerMargin, width: width, height: height, outline: outline, border: border, borderRadius: borderRadius, cursor: cursor }, inputField));
};
//# sourceMappingURL=Input.js.map