import Button from "@material-ui/core/Button";
import MuiStep from "@material-ui/core/Step";
import MuiStepLabel from "@material-ui/core/StepLabel";
import MuiStepper from "@material-ui/core/Stepper";
import Typography from "@material-ui/core/Typography";
import classNames from "classnames";
import React, { useState } from "react";
import { useForm } from "react-hook-form";
import { CustomConnector } from "./CustomConnector";
import { ContentContainer, useMultiStepperStyles } from "./styles";
export const MultiStepper = ({ className, id, width, maxWidth, height, maxHeight, border, borderRadius, outline, padding, margin, backgroundColor, textColor, lineColor, activeLineColor, completedLineColor, steps, onSubmit, currentIcon, processedIcon, unprocessedIcon, allStepsCompletedMessage = "All steps completed", submitButtonText = "Submit", backButtonText = "Back", lastStepNextButtonText = "Finish", nextButtonText = "Next", }) => {
    const classes = useMultiStepperStyles({
        width,
        height,
        maxWidth,
        maxHeight,
        border,
        borderRadius,
        outline,
        padding,
        margin,
        backgroundColor,
        textColor,
    });
    const [activeStep, setActiveStep] = useState(0);
    const { register, handleSubmit, setValue, formState: { errors }, } = useForm();
    const Connector = CustomConnector({
        lineColor,
        activeLineColor,
        completedLineColor,
    });
    const handleNext = () => {
        setActiveStep((prevActiveStep) => prevActiveStep + 1);
    };
    const handleBack = () => {
        setActiveStep((prevActiveStep) => prevActiveStep - 1);
    };
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const onSubmitForm = (data) => {
        onSubmit(data);
    };
    const currentStep = steps[activeStep];
    const isLastStep = activeStep === steps.length - 1;
    return (React.createElement("form", { onSubmit: handleSubmit(onSubmitForm) },
        React.createElement("div", { id: id, className: classNames(classes.root, className) },
            React.createElement(MuiStepper, { activeStep: activeStep, alternativeLabel: true, connector: React.createElement(Connector, null) }, steps.map((step, index) => {
                let icon;
                if (index === activeStep) {
                    icon = step.currentIcon || currentIcon;
                }
                else if (index < activeStep) {
                    icon = step.processedIcon || processedIcon;
                }
                else {
                    icon = step.unprocessedIcon || unprocessedIcon;
                }
                return (React.createElement(MuiStep, { key: step.label },
                    React.createElement(MuiStepLabel, Object.assign({}, (icon && { icon })), step.label)));
            })),
            React.createElement(ContentContainer, null, activeStep === steps.length ? (React.createElement("div", null,
                React.createElement(Typography, { className: classes.instructions }, allStepsCompletedMessage),
                React.createElement(Button, { type: "submit" }, submitButtonText))) : (React.createElement("div", null,
                React.cloneElement(currentStep.component, {
                    register,
                    setValue,
                    errors,
                }),
                React.createElement("div", null,
                    React.createElement(Button, { disabled: activeStep === 0, onClick: handleBack, className: classes.backButton }, backButtonText),
                    React.createElement(Button, { variant: "contained", color: "primary", onClick: handleNext }, isLastStep ? lastStepNextButtonText : nextButtonText))))))));
};
//# sourceMappingURL=MultiStepper.js.map