import React, { useCallback } from "react";
import { FormattedNumberParts } from "react-intl";
import { defaultAmountFormat } from "../../../helpers/formatDate";
const NUMBER_DECIMAL_SEPARATOR = ".";
const NUMBER_THOUSANDS_SEPARATOR = ",";
const NUMBER_DECIMAL_SCALE = 2;
export const FormatNumber = ({ value, format, }) => {
    const { hasDecimalSeparator, decimalSeparator, hasThousandsSeparator, thousandsSeparator, } = format || defaultAmountFormat;
    const addDecimals = useCallback((parts) => {
        const found = parts === null || parts === void 0 ? void 0 : parts.find((part) => part.type === "fraction");
        if (found) {
            return "";
        }
        if (hasDecimalSeparator) {
            return `${decimalSeparator}${"0".repeat(NUMBER_DECIMAL_SCALE)}`;
        }
        return `${NUMBER_DECIMAL_SEPARATOR}${"0".repeat(NUMBER_DECIMAL_SCALE)}`;
    }, [decimalSeparator, hasDecimalSeparator]);
    if (value === null || value === undefined) {
        return React.createElement(React.Fragment, null);
    }
    return (React.createElement(FormattedNumberParts, { value: value }, (parts) => (React.createElement(React.Fragment, null,
        parts.map((part) => {
            if (hasThousandsSeparator &&
                part.value === NUMBER_THOUSANDS_SEPARATOR) {
                return thousandsSeparator;
            }
            if (hasDecimalSeparator &&
                part.value === NUMBER_DECIMAL_SEPARATOR) {
                return decimalSeparator;
            }
            if (part.type === "fraction") {
                return part.value.length <= NUMBER_DECIMAL_SCALE
                    ? part.value +
                        "0".repeat(NUMBER_DECIMAL_SCALE - part.value.length)
                    : part.value.substring(0, NUMBER_DECIMAL_SCALE);
            }
            return part.value;
        }),
        addDecimals(parts)))));
};
//# sourceMappingURL=FormatNumber.js.map