import { TableContainer, Table as MuiTable } from "@material-ui/core";
import classNames from "classnames";
import React from "react";
import { EmptyState } from "./DataState/EmptyState";
import { ErrorState } from "./DataState/ErrorState";
import { useStyle } from "./styles";
import { TableBody } from "./TableBody/TableBody";
import { TableFooter } from "./TableFooter/TableFooter";
import { TableHead } from "./TableHead/TableHead";
import { TableLoadingState } from "./TableLoadingState/TableLoadingState";
export const DEFAULT_ITEMS_PER_PAGE = 10;
export const Table = ({ data, columns, actions, border, pagination = true, onRowClick, error, loading, selectKey = "id", customStyle, className, paginationClassName, actionsNotification, EmptyStateComponent, hoverableTableRow = true, totalItems, page, limit, rowsPerPageOptions, tableFilters, order, orderBy, setPage, setLimit, setTableFilters, setOrderBy, selectedRows = [], tableStatus, setTableStatus, isDisabled, collapsableRows = false, ExpandableRowContent, hasSummaryRow = false, SummaryRowContent, isHighlighted, hiddenHeader, resizeColumns, hideErrorHeader, }) => {
    const classes = useStyle({ border, customStyle, hiddenHeader });
    const renderEmptyState = () => EmptyStateComponent || React.createElement(EmptyState, null);
    const shouldShowEmptyState = !(data === null || data === void 0 ? void 0 : data.length) && !loading && !error;
    const hasFooter = pagination;
    return (React.createElement("div", { className: classes.tableWrapper },
        React.createElement(TableContainer, { className: classNames(classes.root, className) },
            React.createElement(MuiTable, { className: classes.table, stickyHeader: true },
                React.createElement(TableHead, { columns: columns, border: border, customStyle: customStyle, actions: actions, tableStatus: tableStatus, setTableStatus: setTableStatus, order: order, orderBy: orderBy, setOrderBy: setOrderBy, hidden: hiddenHeader, resizeColumns: resizeColumns }),
                React.createElement(TableBody, { columns: columns, data: data, actionsNotification: actionsNotification, selectedRows: selectedRows, selectKey: selectKey, actions: actions, tableStatus: tableStatus, setTableStatus: setTableStatus, setTableFilters: setTableFilters, filters: tableFilters, border: border, hidden: loading || Boolean(error), customStyle: customStyle, hoverableTableRow: hoverableTableRow, onRowClick: onRowClick, isDisabled: isDisabled, collapsableRows: collapsableRows, ExpandableRowContent: ExpandableRowContent, isHighlighted: isHighlighted, hiddenHeader: hiddenHeader }),
                loading && React.createElement(TableLoadingState, { actions: actions, columns: columns })),
            shouldShowEmptyState && renderEmptyState(),
            error && !loading && (React.createElement(ErrorState, { messages: [undefined, error.message], hideErrorHeader: hideErrorHeader }))),
        !error && !loading && hasSummaryRow && !!SummaryRowContent && (React.createElement(SummaryRowContent, { data: data, columns: columns })),
        hasFooter && (React.createElement(TableFooter, { pagination: pagination, paginationClassName: paginationClassName, totalItems: totalItems, limit: limit, page: page, rowsPerPageOptions: rowsPerPageOptions, setTableStatus: setTableStatus, setLimit: setLimit, setPage: setPage }))));
};
//# sourceMappingURL=Table.js.map