var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { IconButton, Tooltip } from "@material-ui/core";
import CheckIcon from "@material-ui/icons/Check";
import CloseIcon from "@material-ui/icons/Close";
import { Skeleton } from "@material-ui/lab";
import { useSnackbar } from "notistack";
import React from "react";
import { getActionsCount } from "../../../helpers/getActionsCount";
import { TableMode } from "../types";
export const ROW_ACTIONS_WIDTH = 30;
export const TableConfirmActions = ({ row, newRow, notify = true, setRow, actions, tableStatus, setTableStatus, }) => {
    const { rowActions } = getActionsCount(actions);
    const { enqueueSnackbar } = useSnackbar();
    const resetTableStatus = {
        errors: undefined,
        tableMode: undefined,
        activeRow: undefined,
        loading: undefined,
    };
    const handleActionCancel = (event) => {
        event.stopPropagation();
        setRow === null || setRow === void 0 ? void 0 : setRow({});
        setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus(resetTableStatus);
    };
    const runAction = () => __awaiter(void 0, void 0, void 0, function* () {
        var _a, _b, _c;
        const tableMode = tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode;
        try {
            setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus({ loading: true });
            switch (tableMode) {
                case TableMode.EDIT:
                    yield ((_a = actions === null || actions === void 0 ? void 0 : actions.onRowEdit) === null || _a === void 0 ? void 0 : _a.call(actions, newRow, row));
                    notify &&
                        enqueueSnackbar("Successfully Saved", {
                            variant: "success",
                            autoHideDuration: 1000,
                        });
                    break;
                case TableMode.DELETE:
                    yield ((_b = actions === null || actions === void 0 ? void 0 : actions.onRowDelete) === null || _b === void 0 ? void 0 : _b.call(actions, row));
                    notify &&
                        enqueueSnackbar("Successfully Removed", {
                            variant: "success",
                            autoHideDuration: 1000,
                        });
                    break;
                case TableMode.ADD:
                    yield ((_c = actions === null || actions === void 0 ? void 0 : actions.onRowAdd) === null || _c === void 0 ? void 0 : _c.call(actions, row));
                    notify &&
                        enqueueSnackbar("Successfully Saved", {
                            variant: "success",
                            autoHideDuration: 1000,
                        });
                    break;
            }
        }
        catch (error) {
            notify && enqueueSnackbar("Action failed");
        }
        finally {
            setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus(resetTableStatus);
        }
    });
    const handleActionConfirm = (event) => __awaiter(void 0, void 0, void 0, function* () {
        event.stopPropagation();
        yield runAction();
    });
    return (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.loading) ? (React.createElement(Skeleton, { width: ROW_ACTIONS_WIDTH * rowActions, animation: "pulse" })) : (React.createElement(React.Fragment, null,
        React.createElement(Tooltip, { title: "Confirm" },
            React.createElement(IconButton, { size: "small", "aria-label": "confirm", onClick: handleActionConfirm },
                React.createElement(CheckIcon, null))),
        React.createElement(Tooltip, { title: "Cancel" },
            React.createElement(IconButton, { size: "small", "aria-label": "cancel", onClick: handleActionCancel },
                React.createElement(CloseIcon, null)))));
};
//# sourceMappingURL=TableConfirmActions.js.map