import DateFnsUtils from "@date-io/date-fns";
import { MenuItem, TableCell, TableRow, TextField } from "@material-ui/core";
import { DatePicker, DateTimePicker, MuiPickersUtilsProvider, } from "@material-ui/pickers";
import classNames from "classnames";
import React from "react";
import { TableColumnAlign } from "../types";
export const TableColumnFilter = ({ columns, onChange, filters, classes, hasActions, }) => {
    const defaultDateFormat = "yyyy-MM-dd";
    const label = "Filter";
    return (React.createElement(TableRow, null,
        hasActions && React.createElement(TableCell, { className: classes.filterRowCell }),
        columns.map((column, inputIndex) => {
            var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
            if (column.columnFilter !== false && column.field !== "id") {
                switch (column.type) {
                    case "amount":
                        return (React.createElement(TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || TableColumnAlign.LEFT },
                            React.createElement(TextField, { type: "number", value: filters[column.field] || "", size: "small", label: label, variant: "outlined", margin: "none", onChange: (e) => onChange(e, column) })));
                    case "date":
                        return (React.createElement(TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || TableColumnAlign.LEFT },
                            React.createElement(MuiPickersUtilsProvider, { utils: DateFnsUtils },
                                React.createElement(DatePicker, { value: filters[column.field] || null, format: defaultDateFormat, label: label, size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column);
                                    } }))));
                    case "date-range":
                        return (React.createElement(TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || TableColumnAlign.LEFT },
                            React.createElement(MuiPickersUtilsProvider, { utils: DateFnsUtils },
                                React.createElement(DatePicker, { value: ((_a = filters[column.field]) === null || _a === void 0 ? void 0 : _a[0]) || null, format: defaultDateFormat.replace(/[:Hms]/g, ""), label: "Date From", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column);
                                    }, maxDate: ((_b = filters[column.field]) === null || _b === void 0 ? void 0 : _b[1]) || null }),
                                React.createElement(DatePicker, { value: ((_c = filters[column.field]) === null || _c === void 0 ? void 0 : _c[1]) || null, format: defaultDateFormat.replace(/[:Hms]/g, ""), label: "Date To", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column, false);
                                    }, minDate: ((_d = filters[column.field]) === null || _d === void 0 ? void 0 : _d[0]) || null }))));
                    case "date-time-range":
                        return (React.createElement(TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || TableColumnAlign.LEFT },
                            React.createElement(MuiPickersUtilsProvider, { utils: DateFnsUtils },
                                React.createElement(DateTimePicker, { value: ((_e = filters[column.field]) === null || _e === void 0 ? void 0 : _e[0]) || null, format: defaultDateFormat, label: "Date From", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column);
                                    }, maxDate: ((_f = filters[column.field]) === null || _f === void 0 ? void 0 : _f[1]) || null }),
                                React.createElement(DateTimePicker, { value: ((_g = filters[column.field]) === null || _g === void 0 ? void 0 : _g[1]) || null, format: defaultDateFormat, label: "Date To", size: "small", disableFuture: true, autoOk: true, clearable: true, onChange: (date) => {
                                        onChange(date, column, false);
                                    }, minDate: ((_h = filters[column.field]) === null || _h === void 0 ? void 0 : _h[0]) || null }))));
                    case "amount-range":
                        return (React.createElement(TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || TableColumnAlign.LEFT },
                            React.createElement(TextField, { type: "number", value: ((_j = filters[column.field]) === null || _j === void 0 ? void 0 : _j[0]) || "", size: "small", label: "Min", variant: "outlined", margin: "none", onChange: (e) => {
                                    onChange(e, column);
                                } }),
                            React.createElement(TextField, { type: "number", value: ((_k = filters[column.field]) === null || _k === void 0 ? void 0 : _k[1]) || "", size: "small", label: "Max", variant: "outlined", margin: "none", onChange: (e) => {
                                    onChange(e, column, false);
                                } })));
                    case "lookup":
                        return (React.createElement(TableCell, { key: inputIndex, className: classNames(classes.filterRowCell, "lookup"), align: column.align || TableColumnAlign.LEFT },
                            React.createElement(TextField, { value: filters[column.field] || "", name: column.field, onChange: (e) => {
                                    onChange(e, column);
                                }, select: true, variant: "outlined", size: "small", label: label },
                                React.createElement(MenuItem, null,
                                    React.createElement("em", null, "None")),
                                Object.values(column.filterEnum || []).map((option, i) => (React.createElement(MenuItem, { key: i, value: option || "" }, column.filterEnum
                                    ? column.filterEnumOptionsLabel
                                    : option))))));
                    default:
                        return (React.createElement(TableCell, { key: inputIndex, className: classes.filterRowCell, align: column.align || TableColumnAlign.LEFT },
                            React.createElement(TextField, { variant: "outlined", size: "small", placeholder: "filter", fullWidth: true, onChange: (e) => {
                                    onChange(e, column);
                                }, value: filters[column.field] || "", label: label })));
                }
            }
            else {
                return React.createElement(TableCell, { className: classes.emptyCell, key: inputIndex });
            }
        })));
};
//# sourceMappingURL=TableColumnFilter.js.map