import { IconButton, TableSortLabel, Tooltip, TableHead as MuiTableHead, TableCell, TableRow, } from "@material-ui/core";
import { Add as AddIcon } from "@material-ui/icons";
import { Resizable } from "re-resizable";
import React, { useCallback } from "react";
import { getActionsCount } from "../../../helpers/getActionsCount";
import { RowPopup } from "../RowPopup/RowPopup";
import { useStyle } from "../styles";
import { ROW_ACTION_SKELETON_WIDTH } from "../TableLoadingState/TableLoadingState";
import { TableColumnAlign, TableMode, TableOrder, } from "../types";
const ENABLE = {
    top: false,
    right: true,
    bottom: false,
    left: false,
    topRight: false,
    bottomRight: false,
    bottomLeft: false,
    topLeft: false,
};
var CellWidthIndex;
(function (CellWidthIndex) {
    CellWidthIndex[CellWidthIndex["MIN"] = 9] = "MIN";
    CellWidthIndex[CellWidthIndex["MAX"] = 54] = "MAX";
})(CellWidthIndex || (CellWidthIndex = {}));
export const TableHead = ({ columns, border, customStyle, actions, tableStatus, setTableStatus, order, orderBy, setOrderBy, hidden = false, resizeColumns = true, }) => {
    var _a;
    const classes = useStyle({ border, customStyle, hiddenHeader: hidden });
    const { actionsCount } = getActionsCount(actions);
    const hasHeaderActions = (actions === null || actions === void 0 ? void 0 : actions.headerActions) && ((_a = actions === null || actions === void 0 ? void 0 : actions.headerActions) === null || _a === void 0 ? void 0 : _a.length) > 0;
    const createSortHandler = (columnId) => () => {
        setOrderBy(columnId);
    };
    const getIsResizable = (enable, resizable) => resizable ? enable : Object.assign(Object.assign({}, enable), { right: resizable });
    const handleOnResizeStop = useCallback((_event, _d, refElement, delta) => {
        const refWidth = parseInt(refElement.style.width.replace("px", "")) || 0;
        const { width: deltaWidth } = delta;
        const cellText = refElement.innerText;
        const minCellWidth = cellText.length * CellWidthIndex.MIN;
        const maxCellWidth = cellText.length * CellWidthIndex.MAX;
        if (deltaWidth < 0 && refWidth < minCellWidth) {
            refElement.style.width = `${minCellWidth}px`;
        }
        else if (deltaWidth > 0 && refWidth > maxCellWidth) {
            refElement.style.width = `${maxCellWidth}px`;
        }
    }, []);
    const SortableLabel = ({ column, }) => (React.createElement(Tooltip, { title: "Sort" },
        React.createElement(TableSortLabel, { active: orderBy === column.field, direction: orderBy === column.field ? order || undefined : TableOrder.ASC, onClick: createSortHandler(column.field) },
            column.label,
            orderBy === column.field ? (React.createElement("span", { style: { display: "none" } }, order === TableOrder.ASC ? "ascending" : "descending")) : null)));
    const AddNewRow = () => (React.createElement(Tooltip, { title: "Add" },
        React.createElement("span", null,
            React.createElement(IconButton, { className: classes.addButton, size: "small", color: "secondary", disabled: !!(tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode), "aria-label": "add", onClick: () => setTableStatus === null || setTableStatus === void 0 ? void 0 : setTableStatus({ tableMode: TableMode.ADD }) },
                React.createElement(AddIcon, null)))));
    return (React.createElement(MuiTableHead, { className: classes.tableHead },
        React.createElement(TableRow, null,
            actionsCount > 0 && (React.createElement(TableCell, { className: classes.tableActionCell, style: { width: actionsCount * ROW_ACTION_SKELETON_WIDTH } },
                React.createElement("span", { className: classes.tableActionWrapper },
                    hasHeaderActions && (React.createElement(RowPopup, { className: classes.addButton, color: "secondary", actions: (actions === null || actions === void 0 ? void 0 : actions.headerActions) || [] })),
                    (actions === null || actions === void 0 ? void 0 : actions.onRowAdd) && React.createElement(AddNewRow, null)))),
            columns.map((column) => (React.createElement(TableCell, Object.assign({ key: `${String(column.field)}` }, (column.additionalCellProps &&
                typeof column.additionalCellProps === "object" && Object.assign({}, column.additionalCellProps)), { align: column.alignHeader || TableColumnAlign.LEFT, className: classes.tableHeadCell }),
                React.createElement(Resizable, { className: resizeColumns ? classes.resizableWrapper : undefined, enable: getIsResizable(ENABLE, resizeColumns), onResizeStop: handleOnResizeStop }, column.sortable ? (React.createElement(SortableLabel, { column: column })) : (column.label))))))));
};
//# sourceMappingURL=TableHead.js.map