import { Checkbox, TextField } from "@material-ui/core";
import React from "react";
import NumberFormat from "react-number-format";
import { defaultAmountFormat } from "../../../helpers/formatDate";
import { getFieldValue } from "../../../helpers/getFieldValue";
import { useStyle } from "../styles";
export const TableInputCell = ({ clearError, setRow, value, hasError, errorMessage, field, column, onChange, }) => {
    const classes = useStyle({});
    const { hasThousandsSeparator, thousandsSeparator, hasDecimalSeparator, decimalSeparator, } = defaultAmountFormat;
    const commonProps = {
        value,
        error: hasError,
        helperText: errorMessage,
        defaultValue: column.defaultValue,
        InputProps: {
            classes: {
                input: classes.inputLabel,
            },
        },
    };
    if (column.type === "amount") {
        return (React.createElement(NumberFormat, Object.assign({}, commonProps, { value: commonProps.value, customInput: TextField, thousandSeparator: hasThousandsSeparator ? thousandsSeparator : ",", decimalSeparator: hasDecimalSeparator ? decimalSeparator : ".", decimalScale: 2, fixedDecimalScale: true, onChange: undefined, onValueChange: (values) => {
                if (onChange) {
                    onChange(values.floatValue, setRow);
                }
                else {
                    setRow === null || setRow === void 0 ? void 0 : setRow((prevState) => (Object.assign(Object.assign({}, prevState), { [field]: values.floatValue })));
                }
            } })));
    }
    else if (column.type === "checkbox") {
        return (React.createElement(Checkbox, { checked: !!value, onChange: (event) => {
                const value = getFieldValue(event.target);
                if (onChange) {
                    onChange(value, setRow);
                }
                else {
                    setRow === null || setRow === void 0 ? void 0 : setRow((prevState) => (Object.assign(Object.assign({}, prevState), { [field]: value })));
                }
            }, inputProps: { "aria-label": "checkbox" } }));
    }
    return (React.createElement(TextField, Object.assign({}, commonProps, { type: column.type || "text", onChange: (event) => {
            event.persist();
            clearError();
            const value = getFieldValue(event.target);
            if (onChange) {
                onChange(value, setRow);
            }
            else {
                setRow === null || setRow === void 0 ? void 0 : setRow((prevState) => (Object.assign(Object.assign({}, prevState), { [field]: value })));
            }
        } })));
};
//# sourceMappingURL=TableInputCell.js.map