import { Collapse, TableCell, TableRow as MuiTableRow, } from "@material-ui/core";
import classNames from "classnames";
import React, { useState } from "react";
import { getDefaultRowValues } from "../../../helpers/getDefaultRowValues";
import { TableActions } from "../TableActions/TableActions";
import { TableRenderCell } from "../TableRenderCell/TableRenderCell";
import { TableMode } from "../types";
import { useTableRowStyles } from "./styles";
import { TableDeleteRow } from "./TableDeleteRow";
import { TableEditRow } from "./TableEditRow";
export const TableRow = ({ row, columns, tableStatus, selectKey, hasActions, selectedRows, actions, onRowClick, setTableStatus, hoverableTableRow, actionsNotification, isDisabled, collapsableRows = false, ExpandableRowContent, isHighlighted, }) => {
    const classes = useTableRowStyles();
    const [newRow, setNewRow] = useState(getDefaultRowValues(columns));
    const [expanded, setExpanded] = useState(false);
    const [actionableRow, setActionableRow] = useState(false);
    const isDisabledRow = (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode)
        ? (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.activeRow) !== row[selectKey]
        : false;
    const isEditMode = (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode) === TableMode.EDIT;
    const isDeleteMode = (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode) === TableMode.DELETE;
    const isSelectedRow = (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.activeRow) === row[selectKey] && row[selectKey] !== undefined;
    const tableRowClasses = classNames(row.className ? row.className : "", {
        [classes.clickableRow]: !!onRowClick,
        [classes.disabledRow]: isDisabledRow,
        [classes.highlightedRow]: isHighlighted
            ? isHighlighted(row) && !isDisabledRow
            : false,
        [classes.actionableRow]: actionableRow,
    });
    const DisplayMode = () => (React.createElement(React.Fragment, null, columns.map((column, cellIndex) => (React.createElement(TableRenderCell, { key: cellIndex, column: column, row: row })))));
    return (React.createElement(React.Fragment, null,
        React.createElement(MuiTableRow, { hover: (tableStatus === null || tableStatus === void 0 ? void 0 : tableStatus.tableMode) ? false : hoverableTableRow, selected: selectedRows.includes(row[selectKey]), className: tableRowClasses, onClick: (e) => {
                if (e.currentTarget.contains(e.target)) {
                    setExpanded((expanded) => !expanded);
                    onRowClick === null || onRowClick === void 0 ? void 0 : onRowClick(row, e);
                }
            } },
            hasActions && (React.createElement(TableActions, { row: row, newRow: newRow, setNewRow: setNewRow, actions: actions, tableStatus: tableStatus, setTableStatus: setTableStatus, selectKey: selectKey, disabled: isDisabled ? !!isDisabled(row) : false, actionsNotification: actionsNotification, setActionableRow: setActionableRow })),
            isSelectedRow ? (React.createElement(React.Fragment, null,
                isEditMode && (React.createElement(TableEditRow, { columns: columns, tableStatus: tableStatus, setTableStatus: setTableStatus, row: newRow, setRow: setNewRow })),
                isDeleteMode && (React.createElement(TableDeleteRow, { tableStatus: tableStatus, columns: columns })))) : (React.createElement(DisplayMode, null))),
        collapsableRows && !!ExpandableRowContent && (React.createElement(MuiTableRow, null,
            React.createElement(TableCell, { colSpan: columns.length + 1, className: classNames(classes.collapsableCell, {
                    [classes.borderBottom]: expanded,
                }) },
                React.createElement(Collapse, { in: expanded, timeout: "auto", unmountOnExit: true },
                    React.createElement(ExpandableRowContent, { row: row, columns: columns })))))));
};
//# sourceMappingURL=TableRow.js.map