import { TableCellProps } from "@material-ui/core";
import { ElementType, ReactNode } from "react";
import { DialogOption } from "../DialogSelect/types";
import { Action } from "./RowPopup/RowPopup";
import { TableEditCellProps } from "./TableRenderCell/TableEditCell";
export declare enum TableOrder {
    ASC = "asc",
    DESC = "desc",
    NONE = ""
}
export declare enum TableColumnAlign {
    LEFT = "left",
    CENTER = "center",
    RIGHT = "right"
}
export declare enum TableMode {
    ADD = "add",
    EDIT = "edit",
    DELETE = "delete"
}
export interface TableProps<T> extends TablePaginationProps<T>, PaginationMeta {
    data: T[];
    columns: Array<TableColumnProps<T>>;
    border?: boolean;
    pagination?: boolean;
    actionsNotification?: boolean;
    actions?: TableActionsType<T>;
    error?: Error | null;
    loading?: boolean;
    selectKey?: keyof T;
    customStyle?: boolean;
    className?: string;
    paginationClassName?: string;
    EmptyStateComponent?: ReactNode;
    hoverableTableRow?: boolean;
    tableStatus?: TableStatus<T>;
    onRowClick?: (row: T, event: React.MouseEvent<HTMLTableRowElement, MouseEvent>) => void;
    setTableStatus?: (status: TableStatus<T>) => void;
    isDisabled?: (row: T, action?: string) => boolean;
    collapsableRows?: boolean;
    ExpandableRowContent?: ElementType<{
        row: T;
        columns: Array<TableColumnProps<T>>;
    }>;
    hasSummaryRow?: boolean;
    SummaryRowContent?: ElementType<{
        data: T[];
        columns?: Array<TableColumnProps<T>>;
    }>;
    selectedRows?: T[keyof T][];
    isHighlighted?: (row: T) => boolean;
    hiddenHeader?: boolean;
    resizeColumns?: boolean;
    alignHeader?: TableColumnAlign;
    hideErrorHeader?: boolean;
}
export interface TablePaginationProps<T> extends TablePaginationState<T> {
    setLimit: (value: number) => void;
    setPage: (value: number) => void;
    setOrderBy: (value: string | number | symbol) => void;
    setTableFilters: (params: Partial<Record<keyof T, unknown>>) => void;
}
export declare type FiltersType<T> = Partial<{
    [K in keyof T]: string | string[];
}>;
export interface TablePaginationState<T> {
    tableFilters: FiltersType<T>;
    orderBy?: string | number | symbol;
    order?: TableOrder.ASC | TableOrder.DESC | undefined;
    rowsPerPageOptions?: number[];
    page: number;
    limit: number;
}
export interface PaginationMeta {
    totalItems?: number;
}
export interface PaginationQuery {
    limit?: number;
    page?: number;
    fields?: string;
    filter?: string;
    sortBy?: string;
    select?: string;
    search?: string;
}
export interface Pagination<T> {
    meta?: PaginationMeta;
    items?: T[];
}
export declare type InputType = "button" | "checkbox" | "color" | "date" | "date-time-local" | "email" | "file" | "hidden" | "image" | "month" | "number" | "password" | "radio" | "range" | "reset" | "search" | "submit" | "tel" | "text" | "time" | "url" | "week" | "date-range" | "amount-range" | "date-time-range";
export declare type CellInputType = InputType | "amount" | "lookup";
export declare type Editable = "always" | "onEdit" | "never";
export interface TableColumnProps<T> {
    field: keyof T;
    lookup?: DialogOption<string>[] | ((data: T) => DialogOption<string>[]);
    defaultValue?: any;
    allowMultiSelect?: boolean;
    type?: CellInputType;
    filterEnum?: {
        [s: string]: string;
    };
    filterEnumOptionsLabel?: string;
    lookupAction?: (query: PaginationQuery, row?: T) => Promise<Pagination<any>>;
    label: string | ReactNode;
    editable?: Editable | ((data: T) => Editable);
    additionalCellProps?: Partial<TableCellProps> | ((data: T) => Partial<TableCellProps>);
    sortable?: boolean;
    filterable?: boolean;
    columnFilter?: boolean;
    align?: TableColumnAlign;
    alignHeader?: TableColumnAlign;
    hidden?: boolean;
    modifier?: (data: T) => ReactNode;
    editModifier?: (props: TableEditCellProps<T>) => JSX.Element | JSX.Element[];
    infiniteScroll?: boolean;
}
export interface TableActionsType<T> {
    onRowAdd?: (data: T) => Promise<void>;
    onRowEdit?: (newData: T, oldData: T) => Promise<void>;
    onRowDelete?: (row: T) => Promise<void>;
    rowActions?: (row: T) => Action<T>[];
    headerActions?: Action<T>[];
    toggleRowActions?: (row: T) => Promise<void>;
    hideEdit?: (row: T) => boolean;
    hideDelete?: (row: T) => boolean;
    disableDeleteTooltip?: string;
}
export interface TableStatus<T> {
    activeRow?: T[keyof T];
    tableMode?: TableMode;
    loading?: boolean;
    errors?: Record<keyof T, string>;
}
