import { defaultAmountFormat } from "./formatDate";
const NUMBER_DECIMAL_SEPARATOR = ".";
const NUMBER_THOUSANDS_SEPARATOR = ",";
const NUMBER_DECIMAL_SCALE = 2;
export const getNumberFormat = (value) => {
    const { hasDecimalSeparator, decimalSeparator, hasThousandsSeparator, thousandsSeparator, } = defaultAmountFormat;
    let decimals = "";
    const numberFormatParts = new Intl.NumberFormat().formatToParts(value);
    const numberFormat = numberFormatParts.reduce((result, part) => {
        if (hasThousandsSeparator && part.value === NUMBER_THOUSANDS_SEPARATOR) {
            return (result += thousandsSeparator || "");
        }
        if (hasDecimalSeparator && part.value === NUMBER_DECIMAL_SEPARATOR) {
            return (result += decimalSeparator || "");
        }
        if (part.type === "fraction") {
            if (part.value.length <= NUMBER_DECIMAL_SCALE) {
                result +=
                    part.value + "0".repeat(NUMBER_DECIMAL_SCALE - part.value.length);
                return result;
            }
            else {
                return (result += part.value.substring(0, NUMBER_DECIMAL_SCALE));
            }
        }
        return (result += part.value);
    }, "");
    const found = numberFormatParts.find((part) => part.type === "faction");
    if (found) {
        decimals = "";
    }
    if (hasDecimalSeparator) {
        decimals = `${decimalSeparator}${"0".repeat(NUMBER_DECIMAL_SCALE)}`;
    }
    decimals = `${NUMBER_DECIMAL_SEPARATOR}${"0".repeat(NUMBER_DECIMAL_SCALE)}`;
    return numberFormat + decimals;
};
//# sourceMappingURL=getNumberFormat.js.map